"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * @classdesc Wraps a response from the Wargaming API.
 */
var APIResponse = function () {
  /**
   * Constructor.
   * @param {Object} data - The response data.
   * @param {BaseClient} data.client - The API client that the response originated
   *   from.
   * @param {string} data.requestRealm - The realm of the API that this response
   *   originated from.
   * @param {string} data.method - The name of the method that was used to get
   *   this response data.
   * @param {Object} data.body - The parsed JSON data from the API.
   */
  function APIResponse(_ref) {
    var client = _ref.client,
        requestRealm = _ref.requestRealm,
        method = _ref.method,
        body = _ref.body;

    _classCallCheck(this, APIResponse);

    /**
     * The API client that the response originated from.
     * @type {BaseClient}
     */
    this.client = client;

    /**
     * The realm of the API that this response originated from.
     * @type {string}
     */
    this.requestRealm = requestRealm;

    /**
     * The name of the API method that gave this response.
     * @type {string}
     */
    this.method = method;

    /**
     * The response's parsed JSON data.
     * @type {Object}
     */
    this.body = body;
  }

  /**
   * The value of the meta object returned in the response.
   * @type {Object}
   */


  _createClass(APIResponse, [{
    key: "meta",
    get: function get() {
      return this.body.meta;
    }

    /**
     * The value of the data object returned in the response.
     * @type {Object}
     */

  }, {
    key: "data",
    get: function get() {
      return this.body.data;
    }
  }]);

  return APIResponse;
}();

exports.default = APIResponse;